pred = readRDS("output/models_pred_disturbance_species_policy.RDS")$pred_dist
pred = pred[pred$species_policy == "Random effect",]
pred$disturbance = factor(pred$any,levels=c(FALSE,TRUE),labels=c("Low","High"))
pred$n_pretty = format(pred$n, scientific=FALSE, big.mark=",", trim=TRUE)

bold = function(strings) {
  strings[1,1] = paste0("bold(\"", strings[1,1], "\")")
  strings = label_parsed(strings) # increases strip height.. looks hard to fix
  return(strings)
}

####################################### plot

p = ggplot(pred[pred$type=="Forest",], aes(x=class_simple, y=estimate, color=disturbance, shape=disturbance)) +
  theme_bw() +
  theme(axis.text=element_text(size=12,color="black"),
        axis.text.y=element_text(face=c(rep("plain",4), "bold")),
        axis.title.y=element_blank(),
        axis.title.x=element_text(size=12),
        axis.ticks=element_line(color="black"),
        panel.border=element_rect(color="black"),
        strip.text=element_text(face=c("bold",rep("plain",5))),
        legend.position=c(1,1),
        legend.justification=c(1,1),
        legend.background=element_rect(color="black"),
        legend.direction="horizontal") +
  geom_errorbar(aes(ymin=lower, ymax=upper), show.legend=FALSE, width=0, position=position_dodge(width=0.3)) +
  geom_point(position=position_dodge(width=0.3), size=2.5) +
  ylab("Proportion core species") +
  scale_x_discrete(limits=rev(sort(unique(pred$class_simple))), expand=c(0.1,0,0.25,0)) +
  scale_shape_manual(values=16:17,breaks=c("Low","High"),labels=c("Low disturbance","High disturbance"),
                     guide=guide_legend(title=NULL, order=1)) +
  scale_color_manual(values=brewer.pal(3, "Set1")[1:2],breaks=c("Low","High"),labels=c("Low disturbance","High disturbance"),
                     guide=guide_legend(title=NULL, order=1)) +
  coord_flip() +
  geom_text(data=pred[pred$disturbance=="Low",], aes(label=n_pretty),
            nudge_x=-0.25, show.legend=FALSE) +
  geom_text(data=pred[pred$disturbance == "High",], aes(label=n_pretty),
            nudge_x=0.25, show.legend=FALSE)

pdf("output/frag_disturbance_simple_horiz.pdf", width=4.75, height=4.75)
print(p)
dev.off()

png("output/frag_disturbance_simple_horiz.png", width=4.75, height=4.75, units="in", res=300)
print(p)
dev.off()

