####################################### setup

# http://stackoverflow.com/questions/33489828/insert-different-images-into-individual-panel-using-ggplot2
# http://stackoverflow.com/questions/32807665/removing-one-tablegrob-when-app.lied-to-a-box-plot-with-a-facet-wrap?answertab=votes#tab-top
annotation_custom2 <- 
function (grob, xmin = -Inf, xmax = Inf, ymin = -Inf, ymax = Inf, data) 
{layer(data = data, stat = StatIdentity, position = PositionIdentity, 
        geom = ggplot2:::GeomCustomAnn,
        inherit.aes = TRUE, params = list(grob = grob, 
                                          xmin = xmin, xmax = xmax, 
                                          ymin = ymin, ymax = ymax))}

data = readRDS("input/model_data.RDS")

data$core = 1:nrow(data) %in% grep("Core", data$Category)
models_pred = readRDS("output/models_pred_latitude_species_policy.RDS")

bold = function(strings) {
        strings[,1] = paste0("\"", strings[,1], "\"")
	strings[1,1] = paste0("bold(", strings[1,1], ")")
	strings = label_parsed(strings) # increases strip height.. looks hard to fix
	return(strings)
}

#######################################

data_short_landscape = do.call("rbind", lapply(split(data,paste(data$Landscape,data$type)), function(study_data){
	out = data.frame(study_data[1,],
			 n_species=nrow(study_data),
			 S=mean(study_data$core))
	SE = sd(study_data$EI.sensitivity) / sqrt(out$n_species)
	return(out)
}))
data_short_landscape_forest = data_short_landscape[data_short_landscape$type == "Forest",]

pred = models_pred$pred[models_pred$pred$covar == "abs_lat" & models_pred$pred$species_policy == "Random effect",]
pred = pred[!is.na(pred$p.value),]

temp = merge(pred, models_pred$mod_tab)
temp = temp[temp$type == "Forest",]
class_simple_num = paste0(as.character(unique(pred$class_simple)), " (",
  format(as.numeric(trimws(temp$n[match(as.character(unique(pred$class_simple)),temp$class_simple)])), big.mark=",", trim=TRUE),
  ")")
names(class_simple_num) = as.character(unique(pred$class_simple))

data_short_landscape$class_simple_num = class_simple_num[data_short_landscape$class_simple]
pred$class_simple_num = class_simple_num[as.character(pred$class_simple)]

df_rug = data[data$type == "Forest",]
df_all = df_rug
df_all$class_simple = "All species"
df_rug = rbind(df_rug, df_all)
df_rug$class_simple_num = pred$class_simple_num[match(df_rug$class_simple, pred$class_simple)]
df_rug = df_rug[! duplicated(paste(df_rug$Landscape, df_rug$class_simple_num)),]

labs = pred[pred$type == "Forest",]
labs = labs[! duplicated(labs$p_adj),]
labs$p_lab = paste0("p = ", round(labs$p_adj, 3))
labs$p_lab[round(labs$p_adj, 3) == 0] = "p < 0.001"

data_short_landscape_forest$class_simple_num = "All species (3,269)"

p_left = ggplot(data_short_landscape_forest, aes(x=abs_lat, y=S)) +
  theme_bw() +
  facet_wrap(~ class_simple_num) +
  scale_color_manual(values=brewer.pal(3,"Set1")[-3],
                     breaks=c(FALSE,TRUE),
                     labels=c("Low disturbance","High disturbance"),
                     guide=guide_legend(title=NULL,order=1,
                     override.aes=list(size=2.5))) +
  theme(axis.text=element_text(color="black"),
        axis.ticks=element_line(color="black"),
        panel.border=element_rect(color="black"),
        legend.position=c(0.51,0.58),
        legend.justification=c(0,0),
        legend.background=element_rect(color="black"),
        legend.box="vertical",
        legend.key.height=unit(1,"lines")) +
  geom_ribbon(data=pred[pred$class_simple == "All species" & pred$type == "Forest",],
              aes(y=NULL,ymin=lower,ymax=upper),color=NA,fill="purple", show.legend=FALSE,alpha=0.2) +
  geom_line(data=pred[pred$class_simple == "All species" & pred$type == "Forest",], aes(y=EI.sensitivity),
            size=1.5, show.legend=FALSE, color="purple") +
  geom_point(aes(size=dataset.rating, color=any)) +
  xlab("Absolute latitude (degrees)") +
  ylab("Proportion core species") +
  scale_size(range=c(1, 4),
             guide = guide_legend(title = "Dataset rating", order=1)) +
  geom_text(data=labs[labs$class_simple_num == "All species (3,269)",], aes(label=p_lab), x=0, y=0.03, hjust=0)

p_right = ggplot(data_short_landscape[data_short_landscape$class_simple_num != "All species (3,269)",], aes(x=abs_lat, y=S)) +
  theme_bw() +
  facet_wrap(~class_simple_num) +
  geom_rug(data=df_rug[df_rug$class_simple_num != "All species (3,269)",], aes(y=NULL)) +  
  theme(axis.text=element_text(color="black"),
        axis.ticks=element_line(color="black"),
        panel.border=element_rect(color="black"),
        legend.position=1:0,
        legend.justification=1:0,
        legend.background=element_rect(color="black"),
        legend.direction="vertical",
        legend.box="vertical",
        legend.key.width=unit(3,"lines"),
        legend.key.height=unit(1,"lines")) +
  geom_ribbon(data=pred[pred$type == "Forest" & pred$class_simple_num != "All species (3,269)",], aes(y=NULL,ymin=lower,ymax=upper),
              fill=brewer.pal(3, "Set1")[1],show.legend=FALSE,alpha=0.2) +
  geom_line(data=pred[pred$type == "Forest" & pred$class_simple_num != "All species (3,269)",], aes(y=EI.sensitivity),
            color=brewer.pal(3, "Set1")[1], size=1.5) +
  xlab("Absolute latitude (degrees)") +
  ylab("Proportion core species") +
  geom_text(data=labs[labs$class_simple_num != "All species (3,269)",], aes(label=p_lab), x=0, y=0.06, hjust=0)

class_list = sort(as.character((unique(pred$class_simple)))) # match w/ panel order for convenience
for(i in 2:length(class_list)){
  print(class_list[i])
  img <- readPNG(paste0("input/icons/", class_list[i], ".png"))
  g <- rasterGrob(img, interpolate=TRUE)
  yrange_panel = ggplot_build(p_right)$layout$panel_params[[i-1]]$y.range # https://gist.github.com/tomhopper/9076152
  yrange = yrange_panel[1] + c(0.65+0.075,0.95) * (yrange_panel[2] - yrange_panel[1])
  print(yrange)
  p_right = p_right + annotation_custom2(g,
                                         ymin=yrange[1]+0.02*(i==993), ymax=yrange[2]-0.02*(i==993),
                                         xmin=2, xmax=14,
                                         data=data_short_landscape[data_short_landscape$class_simple==class_list[i],][1,]
  )
}

pdf("output/frag_lat_logistic_panel_hybrid.pdf", width=0.8*9, height=0.8*7)
plot_grid(p_left, p_right, labels=c("A","B"))
dev.off()

png("output/frag_lat_logistic_panel_hybrid.png", width=0.8*9, height=0.8*7, units="in", res=400)
plot_grid(p_left, p_right, labels=c("A","B"))
dev.off()

