# http://stackoverflow.com/questions/33489828/insert-different-images-into-individual-panel-using-ggplot2
# http://stackoverflow.com/questions/32807665/removing-one-tablegrob-when-app.lied-to-a-box-plot-with-a-facet-wrap?answertab=votes#tab-top
annotation_custom2 <- 
  function (grob, xmin = -Inf, xmax = Inf, ymin = -Inf, ymax = Inf, data) 
  {layer(data = data, stat = StatIdentity, position = PositionIdentity, 
         geom = ggplot2:::GeomCustomAnn,
         inherit.aes = TRUE, params = list(grob = grob, 
                                           xmin = xmin, xmax = xmax, 
                                           ymin = ymin, ymax = ymax))}

data = readRDS("input/model_data.RDS")
all = data
all$class_simple = "All species"
data = rbind(all, data)

class_tab = sapply(split(data$Species.name,data$class_simple),function(x) length(unique(x)))
data$class = paste0(data$class_simple, " (",
                    prettyNum(class_tab,big.mark=",")[data$class_simple], ")")
data$core = as.numeric(1:nrow(data) %in% grep("Core", data$Category))

bold = function(strings) {
  # print(dim(strings))
  strings[1,1] = paste0("bold(\"", strings[1,1], "\")")
  for(i in 2:5)
    strings[i,1] = paste0("\"", strings[i,1], "\"") # quote the string so we don't try to parse it (putting space after comma, etc.)
  strings = label_parsed(strings) # increases strip height.. looks hard to fix
  # print(strings)
  return(strings)
}

data_short_class = do.call("rbind", lapply(split(data,paste(data$class,data$Landscape)), function(study_data){
  out = data.frame(study_data[1,],
                   n_species=length(unique(study_data$Species.name)), #nrow(study_data),
                   S=mean(study_data$EI.sensitivity),
                   prop_core=mean(study_data$core))
  return(out)
}))

### plot (Edge Sensitivity)

countries = readOGR(dsn="input/countries", layer="countries") # WORLD_BORDERS is more accurate.. probably better for final figures
countries = fortify(countries)

# https://stackoverflow.com/questions/20624507/smoother-gradient-bar-legend-with-pdf
# note: multi-line title looks ugly -- numbers pushed all the way down and label.vjust doesn't
# seem to help.  Maybe try newest dev version.
# https://github.com/tidyverse/ggplot2/issues/2397 (weird bug?)
# https://github.com/tidyverse/ggplot2/commit/d25ae78100fa700f55dd46f8a0cb999d8ddfdcd8
# "guide_colorbar() [...] can handle multi-line titles"
data_short_class = data_short_class[order(data_short_class$n_species, decreasing=TRUE),]

p = ggplot() +
  geom_polygon(data=countries, aes(long,lat,group=group), fill=NA, colour="darkgray", size=0.4) +
  geom_point(data=data_short_class, fill="lightblue",
             aes(x=long,y=lat, size=n_species), color="black", shape=21, alpha=0.75) +
  facet_wrap(~ class, nrow=3, labeller=bold) +
  guides(size = guide_legend(title="Number of \nspecies",order=2)) +
  scale_size(breaks=c(250,500,1000)) +
  coord_fixed(xlim=range(data_short_class$long),ylim=range(data_short_class$lat) + c(-3,0)) +
  theme_bw() +
  theme(axis.line=element_blank(),
        plot.title=element_text(hjust=0.5),
        axis.text.x=element_blank(),
        axis.text.y=element_blank(),
        axis.ticks=element_blank(),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        panel.grid.major=element_blank(),
        panel.grid.minor=element_blank(),
        legend.background = element_rect(fill=NULL,color="black"),
        legend.position=c(0.9,0),
        legend.justification =1:0,
        legend.margin=margin(4,12,4,4))

class_list = sort(as.character((unique(data_short_class$class_simple)))) # match w/ panel order for convenience
for(i in 2:length(class_list)){
  print(class_list[i])
  img <- readPNG(paste0("input/icons/", class_list[i], ".png"))
  g <- rasterGrob(img, interpolate=TRUE)
  yrange_panel = ggplot_build(p)$layout$panel_params[[i]]$y.range # https://gist.github.com/tomhopper/9076152
  yrange = yrange_panel[1] + 0.6*c(0.05,0.45) * (yrange_panel[2] - yrange_panel[1])
  xrange_panel = ggplot_build(p)$layout$panel_params[[i]]$x.range
  xrange = xrange_panel[1] + 0.6*c(0.025,0.15) * (xrange_panel[2] - xrange_panel[1])
  p = p + annotation_custom2(g,
                             ymin=yrange[1], ymax=yrange[2],
                             xmin=xrange[1], xmax=xrange[2],
                             data=data_short_class[data_short_class$class_simple==class_list[i],][1,]
  )
}

pdf("output/frag_lat_map_size.pdf", width=7, height=4.5)
print(p)
dev.off()

png("output/frag_lat_map_size.png", width=7, height=4.5, units="in", res=300)
print(p)
dev.off()

