# http://stackoverflow.com/questions/33489828/insert-different-images-into-individual-panel-using-ggplot2
# http://stackoverflow.com/questions/32807665/removing-one-tablegrob-when-app.lied-to-a-box-plot-with-a-facet-wrap?answertab=votes#tab-top
annotation_custom2 <- 
function (grob, xmin = -Inf, xmax = Inf, ymin = -Inf, ymax = Inf, data) 
{layer(data = data, stat = StatIdentity, position = PositionIdentity, 
        geom = ggplot2:::GeomCustomAnn,
        inherit.aes = TRUE, params = list(grob = grob, 
                                          xmin = xmin, xmax = xmax, 
                                          ymin = ymin, ymax = ymax))}

models_pred = readRDS("output/models_pred_multinomial_habitat_disturbance.RDS")

pred = do.call("rbind", lapply(models_pred, function(x) x$pred))
pred$disturbance = factor(pred$any,levels=c(FALSE,TRUE),labels=c("Low","High"))
pred$n_pretty = format(pred$n, scientific=FALSE, big.mark=",", trim=TRUE)

bold = function(strings) {
  strings[1,1] = paste0("bold(\"", strings[1,1], "\")")
  strings = label_parsed(strings) # increases strip height.. looks hard to fix
  return(strings)
}

####################################### plot

sel = pred$type=="Matrix"  & pred$class_simple %in% c("All species") & pred$disturbance == "High"

# https://github.com/tidyverse/ggplot2/issues/2452
p = ggplot(pred, aes(x=disturbance, y=EI.sensitivity, color=type, shape=type)) +
  theme_bw() +
  scale_color_manual(values=brewer.pal(4, "Set1")[c(3,2,4)],
                     guide=guide_legend(title="Habitat", order=1)) +
  scale_shape(guide=guide_legend(title="Habitat", order=1)) +
  facet_wrap(~class_simple, labeller=bold) + # scales="free_y", 
  theme(axis.text=element_text(color="black"),
        axis.text.x=element_text(angle=45, hjust=1, vjust=1),        
        axis.ticks=element_line(color="black"),
        panel.border=element_rect(color="black"),
        strip.text=element_text(face=c("bold",rep("plain",5))),
        legend.position=1:0,
        legend.justification =1:0,
        legend.background=element_rect(color="black"),
        legend.box="vertical") +
  geom_errorbar(aes(ymin=lower, ymax=upper), show.legend=FALSE, width=0, position=position_dodge(width=0.3)) +
  geom_point(position=position_dodge(width=0.3)) +
  ylab("Proportion of species") +
  geom_text(data=pred[pred$type=="Forest",], aes(label=n_pretty),
            size=3.5, nudge_x=-0.175, nudge_y=0.015, hjust=1, show.legend=FALSE) +
  geom_text(data=pred[pred$type=="Matrix" & ! sel,],
          aes(label=n_pretty),
          size=3.5, nudge_x=-0.055, nudge_y=0.015, hjust=1, show.legend=FALSE) +
  geom_text(data=pred[pred$type=="Generalist",], aes(label=n_pretty),
          size=3.5, nudge_x=0.2, nudge_y=0, hjust=0, show.legend=FALSE) +
  geom_text(data=pred[sel,],
            aes(label=n_pretty),
            size=3.5, nudge_x=0.4, nudge_y=0.015, hjust=1, show.legend=FALSE) +
  xlab("Severity of disturbance")

class_list = sort(setdiff(unique(pred$class_simple),c("All species")))
for(i in 1:length(class_list)){
  print(class_list[i])
  img <- readPNG(paste0("input/icons/", class_list[i], ".png"))
  g <- rasterGrob(img, interpolate=TRUE)
  p = p + annotation_custom2(g,
                             ymin=0.81+.02*(i==3), ymax=0.91-0.02*(i==3),
                             xmin=0.1, xmax=1.1,
                             data=pred[pred$class_simple==class_list[i],][1,]
  )
}

pdf("output/multinomial_disturbance.pdf", width=7, height=7)
print(p)
dev.off()

png("output/multinomial_disturbance.png", width=7, height=7, units="in", res=300)
print(p)
dev.off()

####################################### model

mod_tab = do.call("rbind", lapply(1:length(models_pred), function(i){
  out = data.frame(tidy(models_pred[[i]][[1]]))
  out$class_simple = models_pred[[i]][["pred"]]$class_simple[1]
  return(out)
}))

mod_tab = mod_tab[mod_tab$term %in% c("b_muGeneralist_anyTRUE","b_muMatrix_anyTRUE"),] # not reporting the intercepts...
mod_tab = mod_tab[order(mod_tab$class_simple),]

data = readRDS("input/model_data.RDS")
all = data
all$class_simple = "All species"
data = rbind(data, all)
data = data[data$type %in% c("Forest","Matrix","Generalist"),]

mod_tab$n = prettyNum(table(data$class_simple), bigMark=",")[mod_tab$class_simple]

back_trans = exp(cbind(mod_tab$estimate, mod_tab$estimate - qnorm(0.975)*mod_tab$std.error, mod_tab$estimate + qnorm(0.975)*mod_tab$std.error)) - 1
colnames(back_trans) = c("estimate_back","lower","upper")
mod_tab = cbind(mod_tab, back_trans)

write.csv(mod_tab, "output/mod_tab_mult_dist.csv", row.names=FALSE)

