data = readRDS("input/model_data.RDS")
data$class_raw = data$class_simple

data_all = data
data_all$class_simple = "All species"
data_class = rbind(data, data_all)

data_class$type = factor(data_class$type,
        levels=c("Forest","Matrix","Generalist")) # when we subset, can lose some levels o.w.
data_class = data_class[! is.na(data_class$type),]

######################### checks for Matt

df = data_class[data_class$class_simple %in% "All species",]
round(prop.table(table(df$type, cut(df$abs_lat,seq(0,60,by=10))),2),3)
table(df$type, cut(df$abs_lat,seq(0,60,by=10)))
tapply(df$PID, cut(df$abs_lat,seq(0,60,by=10)), function(x)length(unique(x)))

######################### models

model_mat = expand.grid(class_simple=unique(data_class$class_simple),
	covars=list("abs_lat"),
	stringsAsFactors=FALSE)

cl = makeCluster(5, type = "SOCK", outfile="")
registerDoSNOW(cl)
clusterCall(cl, function(){
require(unixtools)
dir.create(t <- paste0("temp/", Sys.getpid()), FALSE, TRUE, "0700")
set.tempdir(t)
})
out = foreach(i=1:nrow(model_mat), .packages=c("rstan","brms","reshape2")) %dopar% {
	print(paste0("STARTING: ", i))
	attach(model_mat[i,])

	df = data_class[data_class$class_simple %in% class_simple,]

        n_pred=100
	newdata = data.frame(abs_lat = seq(min(df$abs_lat), max(df$abs_lat), length=n_pred))
        newdata$name = "new_gp"

        if(length(unique(df$type)) == 2){
                if(class_simple != "All species"){
                        mod = brm(type ~ abs_lat + (1 | name) + (1 | Species.name), # Forest < Matrix, so we predict P(Matrix)..
                        algorithm = "meanfield",
                        save_ranef = FALSE, save_dso = FALSE, elbo_samples = 2500, tol_rel_obj=0.001, adapt_iter=500, grad_samples=5, seed=1,
                        prior = prior(normal(0,5), class = Intercept) + 
                                prior(normal(0,0.1), class = b) +
                                prior(normal(0,1), class = sd),                       
                        data = df,
                        family = bernoulli())
                } else{
                        mod = brm(type ~ abs_lat + (1 | name) + (abs_lat | class_raw) + (1 | Species.name), # Forest < Matrix, so we predict P(Matrix)..
                        algorithm = "meanfield",
                        save_ranef = FALSE, save_dso = FALSE, elbo_samples = 2500, tol_rel_obj=0.001, adapt_iter=500, grad_samples=5, seed=1,
                        prior = prior(normal(0,5), class = Intercept) +
                                prior(normal(0,0.1), class = b) +
                                prior(normal(0,1), class = sd),
                        data = df,
                        family = bernoulli())
                }
                pred = data.frame(fitted(mod, newdata = newdata, allow_new_levels=TRUE))
                pred = cbind(1-pred, pred, x1=NA, x2=NA, x3=NA, x4=NA) # Order should be F, M, G
        } else{
                if(class_simple != "All species"){
                        mod = brm(type ~ abs_lat + (1 | name) + (1 | Species.name),
                        algorithm = "meanfield", # "fullrank" did not converge by 1e4 iter (i=6)
                        save_ranef = FALSE, save_dso = FALSE, elbo_samples = 2500, tol_rel_obj=0.001, adapt_iter=500, grad_samples=5, seed=1,
                        prior = prior(normal(0,5), class = Intercept) + 
                                prior(normal(0,0.1), class = b) +
                                prior(normal(0,1), class = sd, dpar="muGeneralist") +
                                prior(normal(0,1), class = sd, dpar="muMatrix"),                        
                        data = df,
                        family = categorical())
                } else{
                        mod = brm(type ~ abs_lat + (1 | name) + (abs_lat | class_raw) + (1 | Species.name),
                        algorithm = "meanfield", 
                        save_ranef = FALSE, save_dso = FALSE, elbo_samples = 2500, tol_rel_obj=0.001, adapt_iter=500, grad_samples=5, seed=1,
                        prior = prior(normal(0,5), class = Intercept) + 
                                prior(normal(0,0.1), class = b) +
                                prior(normal(0,1), class = sd, dpar="muGeneralist") +
                                prior(normal(0,1), class = sd, dpar="muMatrix"),
                        data = df,
                        family = categorical()) # see get_prior(...)
                }
                # use "fitted" instead of "predict", since we don't want to perform a posterior predictive check..
                pred = data.frame(fitted(mod, newdata = newdata, re_formula=NA, allow_new_levels=TRUE))
        }

        colnames(pred)[c(1,5,9)] = c("Forest", "Matrix", "Generalist")
        pred_melt = melt(pred[,c(1,5,9)], id.vars=NULL)
        pred_melt$lower = melt(pred[,c(1,5,9) + 2], id.vars=NULL)$value
        pred_melt$upper = melt(pred[,c(1,5,9) + 3], id.vars=NULL)$value
        colnames(pred_melt)[1:2] = c("type", "EI.sensitivity")
        pred = pred_melt
	pred$class_simple = class_simple
        pred$abs_lat = rep(newdata$abs_lat, times=3) # messy but whatever

       	### output
	out = list(mod=mod,
                pred=pred)
	print(paste0("FINISHED: ", i))
	return(out)
}
stopCluster(cl)

saveRDS(out, "output/models_pred_multinomial_habitat_latitude.RDS")

############### paper text: prob forest at max vs min lat

summary(out[[5]]$mod)
range(data_class$abs_lat)

samps = posterior_samples(out[[5]]$mod,
                          pars = paste0("b_",c("muMatrix_Intercept","muGeneralist_Intercept","muMatrix_abs_lat","muGeneralist_abs_lat")))

newdata = data.frame(abs_lat = min(data_class$abs_lat), name = "new_gp")
probs_low = fitted(out[[5]]$mod, newdata = newdata, re_formula=NA, allow_new_levels=TRUE, summary=FALSE)
p_forest_low = probs_low[1:1000,,][,1]

newdata = data.frame(abs_lat = max(data_class$abs_lat), name = "new_gp")
probs_high = fitted(out[[5]]$mod, newdata = newdata, re_formula=NA, allow_new_levels=TRUE, summary=FALSE)
p_forest_high = probs_high[1:1000,,][,1]
quantile(p_forest_low / p_forest_high, c(0.025,0.5,0.975)) # turns out MB just wanted a point est. but w/e

