# http://stackoverflow.com/questions/33489828/insert-different-images-into-individual-panel-using-ggplot2
# http://stackoverflow.com/questions/32807665/removing-one-tablegrob-when-app.lied-to-a-box-plot-with-a-facet-wrap?answertab=votes#tab-top
annotation_custom2 <- 
function (grob, xmin = -Inf, xmax = Inf, ymin = -Inf, ymax = Inf, data) 
{layer(data = data, stat = StatIdentity, position = PositionIdentity, 
        geom = ggplot2:::GeomCustomAnn,
        inherit.aes = TRUE, params = list(grob = grob, 
                                          xmin = xmin, xmax = xmax, 
                                          ymin = ymin, ymax = ymax))}

data = readRDS("input/model_data.RDS")

models_pred = readRDS("output/models_pred_multinomial_habitat_latitude.RDS")
pred=do.call("rbind",lapply(models_pred,function(x) x$pred))

bold = function(strings) {
	strings[1,1] = paste0("bold(\"", strings[1,1], "\")")
	strings = label_parsed(strings) # increases strip height.. looks hard to fix
	return(strings)
}

####################################### plots

# https://github.com/tidyverse/ggplot2/issues/2452
p = ggplot(data=pred, aes(x=abs_lat, y=EI.sensitivity, color=type)) +
	theme_bw() +
	facet_wrap(~class_simple, labeller=bold) + # scales="free_y"
	theme(axis.text=element_text(color="black"),
		axis.ticks=element_line(color="black"),
		panel.border=element_rect(color="black"),
		strip.text=element_text(face=c("bold",rep("plain",5))),
		legend.position=1:0,
                legend.justification=1:0,
		legend.background=element_rect(color="black"),
		legend.box="vertical",
		legend.key.width=unit(3,"lines"),
		legend.key.height=unit(1,"lines")) +
	geom_ribbon(aes(ymin=lower,ymax=upper,fill=type), color=NA, alpha=0.2, show.legend=FALSE) +
	geom_line(size=1.5) +
	xlab("Absolute latitude") +
	ylab("Proportion of species") +
        scale_color_manual(values=brewer.pal(4, "Set1")[c(3,2,4)],
		guide=guide_legend(title="Habitat", order=1)) +
        scale_fill_manual(values=brewer.pal(4, "Set1")[c(3,2,4)])

class_list = sort(as.character((unique(pred$class_simple)))) # match w/ panel order for convenience
for(i in 2:length(class_list)){
  print(class_list[i])
  img <- readPNG(paste0("input/icons/", class_list[i], ".png"))
  g <- rasterGrob(img, interpolate=TRUE)
  yrange_panel = ggplot_build(p)$layout$panel_params[[i]]$y.range # https://gist.github.com/tomhopper/9076152
  yrange = yrange_panel[1] + c(0.62,0.77) * (yrange_panel[2] - yrange_panel[1])
  print(yrange)
  p = p + annotation_custom2(g,
                             ymin=yrange[1]+0.02*(i==993), ymax=yrange[2]-0.02*(i==993),
                             xmin=2, xmax=10,
                             data=pred[pred$class_simple==class_list[i],][1,]
  )
}

cairo_pdf("output/frag_lat_multinomial_habitat.pdf", width=7, height=7)
print(p)
dev.off()

png("output/frag_lat_multinomial_habitat.png", width=7, height=7, units="in", res=300)
print(p)
dev.off()

####################################### model table

mod_tab = do.call("rbind", lapply(1:length(models_pred), function(i){
  out = data.frame(tidy(models_pred[[i]][[1]]))
  out$class_simple = models_pred[[i]][["pred"]]$class_simple[1]
  return(out)
}))
mod_tab = mod_tab[mod_tab$term %in% c("b_muMatrix_abs_lat","b_muGeneralist_abs_lat"),]
mod_tab = mod_tab[order(mod_tab$class_simple),]

data = readRDS("input/model_data.RDS")
all = data
all$class_simple = "All species"
data = rbind(data, all)
data = data[data$type %in% c("Forest","Matrix","Generalist"),]

mod_tab$n = prettyNum(table(data$class_simple), bigMark=",")[mod_tab$class_simple]

back_trans = exp(cbind(mod_tab$estimate, mod_tab$estimate - qnorm(0.975)*mod_tab$std.error, mod_tab$estimate + qnorm(0.975)*mod_tab$std.error)) - 1
colnames(back_trans) = c("estimate_back","lower","upper")
mod_tab = cbind(mod_tab, back_trans)

write.csv(mod_tab, "output/mod_tab_mult_lat.csv", row.names=FALSE)

