# http://stackoverflow.com/questions/33489828/insert-different-images-into-individual-panel-using-ggplot2
# http://stackoverflow.com/questions/32807665/removing-one-tablegrob-when-app.lied-to-a-box-plot-with-a-facet-wrap?answertab=votes#tab-top
annotation_custom2 <- 
  function (grob, xmin = -Inf, xmax = Inf, ymin = -Inf, ymax = Inf, data) 
  {layer(data = data, stat = StatIdentity, position = PositionIdentity, 
         geom = ggplot2:::GeomCustomAnn,
         inherit.aes = TRUE, params = list(grob = grob, 
                                           xmin = xmin, xmax = xmax, 
                                           ymin = ymin, ymax = ymax))}

pred = readRDS("output/models_pred_disturbance_species_policy.RDS")$pred_dist
family = readRDS("output/models_pred_disturbance_order_family.RDS")$pred_dist
family$species_policy = "Family random effect"
pred = rbind.fill(pred, family)
#
pred = pred[pred$species_policy != "None",]
pred$disturbance = factor(pred$any,levels=c(FALSE,TRUE),labels=c("Low","High"))
pred$n_pretty = format(pred$n, scientific=FALSE, big.mark=",", trim=FALSE)

bold = function(strings) {
  strings[,1] = paste0("\"",strings[,1],"\"")
  strings[1,1] = paste0("bold(", strings[1,1], ")")
  strings = label_parsed(strings) # increases strip height.. looks hard to fix
  return(strings)
}

####################################### plot

pred = pred[pred$type == "Forest" & pred$species_policy != "none",]
pred$species_policy = revalue(pred$species_policy, c("Drop duplicates"="Duplicates",
                       "Family random effect"="Order+Family",
                       "Random effect"="Species"))

# https://github.com/tidyverse/ggplot2/issues/2452
p = ggplot(pred,
          aes(x=species_policy, y=estimate, color=disturbance, shape=disturbance)) +
  theme_bw() +
  scale_shape_manual(values=16:17,breaks=c("Low","High"),labels=c("Low disturbance","High disturbance"),
                     guide=guide_legend(title=NULL, order=1)) +
  scale_color_manual(values=brewer.pal(3, "Set1")[1:2],breaks=c("Low","High"),labels=c("Low disturbance","High disturbance"),
                     guide=guide_legend(title=NULL, order=1)) +
  facet_wrap(~class_simple, labeller=bold) + # scales="free_y", 
  theme(axis.text=element_text(color="black"),
        axis.text.x=element_text(angle=45, hjust=1, vjust=1),        
        axis.title.x=element_blank(),
        axis.ticks=element_line(color="black"),
        panel.border=element_rect(color="black"),
        strip.text=element_text(face=c("bold",rep("plain",5))),
        legend.position=1:0,
        legend.justification =1:0,
        legend.background=element_rect(color="black"),
        legend.box="vertical") +
  geom_errorbar(aes(ymin=lower, ymax=upper), show.legend=FALSE, width=0, position=position_dodge(width=0.3)) +
  geom_point(position=position_dodge(width=0.3)) +
  ylab("Proportion core species") +
  geom_text(data=pred[pred$disturbance == "Low",], aes(label=n_pretty), size=3,
            nudge_x=-0.2, nudge_y=0, hjust=1, show.legend=FALSE) +
  geom_text(data=pred[pred$disturbance == "High",], aes(label=n_pretty), size=3,
            nudge_x=-0.05, nudge_y=0, hjust=1, show.legend=FALSE) +  
  coord_cartesian(xlim=c(0.5,3.5))

class_list = sort(setdiff(unique(pred$class_simple),c("All species")))
for(i in 1:length(class_list)){
  print(class_list[i])
  img <- readPNG(paste0("input/icons/", class_list[i], ".png"))
  g <- rasterGrob(img, interpolate=TRUE)
  p = p + annotation_custom2(g,
                             ymin=0.75+.02*(i==3), ymax=0.85-0.02*(i==3),
                             xmin=0.1, xmax=1.1,
                             data=pred[pred$class_simple==class_list[i],][1,]
  )
}

pdf("output/sensitivity.pdf", width=7, height=7)
print(p)
dev.off()

png("output/sensitivity.png", width=7, height=7, units="in", res=300)
print(p)
dev.off()

