# http://stackoverflow.com/questions/33489828/insert-different-images-into-individual-panel-using-ggplot2
# http://stackoverflow.com/questions/32807665/removing-one-tablegrob-when-app.lied-to-a-box-plot-with-a-facet-wrap?answertab=votes#tab-top
annotation_custom2 <- 
function (grob, xmin = -Inf, xmax = Inf, ymin = -Inf, ymax = Inf, data) 
{layer(data = data, stat = StatIdentity, position = PositionIdentity, 
        geom = ggplot2:::GeomCustomAnn,
        inherit.aes = TRUE, params = list(grob = grob, 
                                          xmin = xmin, xmax = xmax, 
                                          ymin = ymin, ymax = ymax))}

models_pred = readRDS("output/models_pred_latitude_species_policy.RDS")

bold = function(strings) {
        strings[,1] = paste0("\"", strings[,1], "\"")
	strings[1,1] = paste0("bold(", strings[1,1], ")")
	strings = label_parsed(strings) # increases strip height.. looks hard to fix
	return(strings)
}

### plot

pred = models_pred$pred[models_pred$pred$covar == "abs_lat" & models_pred$pred$species_policy == "Drop duplicates",]
pred = pred[!is.na(pred$p.value),]

temp = merge(pred, models_pred$mod_tab, by=c("class_simple","type"))
temp = temp[temp$type == "Forest",]
class_simple_num = paste0(as.character(unique(pred$class_simple)), " (",
  format(as.numeric(trimws(temp$n[match(as.character(unique(pred$class_simple)),temp$class_simple)])), big.mark=",", trim=TRUE),
  ")")
names(class_simple_num) = as.character(unique(pred$class_simple))

pred$class_simple_num = class_simple_num[as.character(pred$class_simple)]

temp = p.adjust(unique(pred$p.value),"fdr")
names(temp) = unique(pred$p.value)
pred$p_adj = temp[as.character(pred$p.value)]
pred$FDR_pval_cut = cut(pred$p_adj, breaks=c(0,.05,.1,1))
levels(pred$FDR_pval_cut) = paste0(levels(pred$FDR_pval_cut), " ")

p = ggplot() +
  theme_bw() +
  facet_wrap(~class_simple_num, labeller=bold) +
  theme(axis.text=element_text(color="black"),
        axis.ticks=element_line(color="black"),
        panel.border=element_rect(color="black"),
        strip.text=element_text(face=c("bold",rep("plain",5))),
        legend.position=1:0,
        legend.justification=1:0,
        legend.background=element_rect(color="black"),
        legend.direction="vertical",
        legend.box="vertical",
        legend.key.width=unit(3,"lines"),
        legend.key.height=unit(1,"lines")) +
  geom_ribbon(data=pred[pred$type == "Forest",], aes(x=abs_lat,y=NULL,ymin=lower,ymax=upper),
              fill=brewer.pal(3, "Set1")[1],show.legend=FALSE,alpha=0.2) +
  geom_line(data=pred[pred$type == "Forest",], aes(x=abs_lat,y=EI.sensitivity, linetype=FDR_pval_cut),
            color=brewer.pal(3, "Set1")[1], size=1.5) +
  xlab("Absolute latitude") +
  ylab("Proportion core species") +
  scale_fill_manual(values=brewer.pal(3, "Set1")) +
  scale_linetype_manual(values=c("solid","31","34"),
                        guide = guide_legend(title = bquote("FDR adjusted "*italic("p")*"-value  ")),
                        drop=TRUE)

class_list = sort(as.character((unique(pred$class_simple)))) # match w/ panel order for convenience
for(i in 2:length(class_list)){
  print(class_list[i])
  img <- readPNG(paste0("input/icons/", class_list[i], ".png"))
  g <- rasterGrob(img, interpolate=TRUE)
  yrange_panel = ggplot_build(p)$layout$panel_params[[i]]$y.range # https://gist.github.com/tomhopper/9076152
  yrange = yrange_panel[1] + c(0.8,0.95) * (yrange_panel[2] - yrange_panel[1])
  print(yrange)
  p = p + annotation_custom2(g,
                             ymin=yrange[1]+0.02*(i==993), ymax=yrange[2]-0.02*(i==993),
                             xmin=2, xmax=10,
                             data=data_short_landscape[data_short_landscape$class_simple==class_list[i],][1,]
  )
}

cairo_pdf("output/DROP_DUPLICATES_frag_lat_logistic_habitat.pdf", width=7, height=7)
print(p)
dev.off()

png("output/DROP_DUPLICATES_frag_lat_logistic_habitat.png", width=7, height=7, units="in", res=300)
print(p)
dev.off()

