model_data = readRDS("input/model_data.RDS")
model_data = model_data[model_data$type %in% c("Forest","Matrix","Generalist"),]

model_data$Core = str_split_fixed(model_data$Category, " ", 2)[,2]

data_all = model_data
data_all$class_simple = "All species"
data_all = rbind(model_data, data_all)

data_all_2 = data_all
data_all_2$type = "Any habitat"
data_all_2 = rbind(data_all, data_all_2)

data_split = split(data_all_2, data_all_2$class_simple)

main_tab = rbind.fill(lapply(data_split, function(x){
  tab = addmargins(table(x$type, x$Core), 2)
  out = data.frame(class_simple=x$class_simple[1],
                   Type=rownames(tab),
                   as.data.frame.matrix(tab))
  return(out)
}))
write.csv(main_tab, "output/main_tab.csv",
          row.names=FALSE)

prop_tab = rbind.fill(lapply(data_split, function(x){
  tab = prop.table(table(x$type, x$Core), margin=1)
  out = data.frame(class_simple=x$class_simple[1],
                   Type=rownames(tab),
                   as.data.frame.matrix(tab))
  return(out)
}))
write.csv(prop_tab, "output/prop_tab.csv",
          row.names=FALSE)

####################################### count total/unique species

data = readRDS("input/model_data.RDS")

nrow(data) # 6,848 total
length(unique(data$Species.name)) # 4,489 unique

data = data[data$type %in% c("Forest","Matrix","Generalist"),]

nrow(data) # 4,747
length(unique(data$Species.name)) # 3,275

tapply(data$Species.name, data$class_simple, function(x) length(x))
# Arthropods      Birds  Herptiles    Mammals
#       1968       2150        310        319
tapply(data$Species.name, data$class_simple, function(x) length(unique(x)))
# Arthropods      Birds  Herptiles    Mammals
#       1803        997        249        226

####################################### simple table

data = readRDS("input/model_data.RDS")

total = aggregate(Species.name ~ class_simple, data = data, function(x) c(all=length(x),unique=length(unique(x))))
data = data[! is.na(data$type),]
main_type = aggregate(Species.name ~ class_simple, data = data, function(x) c(all=length(x),unique=length(unique(x))))

out = data.frame(total, main_type)
write.csv(out, "output/sample_size_complete.csv", row.names=FALSE)

#######################################
# compare forest core ES in low vs high disturbance areas...

data = readRDS("input/model_data.RDS")
data = data[! is.na(data$type),]

data$group = data$class_simple # UPDATE
data = data[! is.na(data$EI.sensitivity),]

data = data[data$Category == "Forest Core",]

aggregate(EI.sensitivity ~ any, data = data,
          function(x) c(mean=mean(x),se=sd(x)/sqrt(length(x))))
0.748898051 / 0.560254602 # 1.33671

####################################### look at change in prop. across lat. gradient

models_pred = readRDS("output/models_pred_latitude_species_policy.RDS")
pred = models_pred$pred[models_pred$pred$covar == "abs_lat" & models_pred$pred$species_policy == "Random effect",]

prop_range = range(pred[pred$class_simple == "All species" & pred$type == "Forest",]$EI.sensitivity)
prop_range[2] / prop_range[1] # 6.170713

#######################################
# "A substantial 52% of forest species tend to avoid edges in low disturbance regions"

model_data = readRDS("input/model_data.RDS")
model_data = model_data[model_data$type %in% "Forest" & ! model_data$any,]
prop.table(table(model_data$Category))

