######################### basic setup

data = readRDS("input/model_data.RDS")

data$group = data$class_simple # UPDATE
data$y = as.numeric(1:nrow(data) %in% grep("Core", data$Category))

data_class = data[which(data$migratory_status != "full migrant"),] # need "which" since data includes non-birds

######################### models

model_mat = expand.grid(class_simple=unique(data_class$class_simple),
	covars=list("any","natural","hist_loss_binary"),        
	type="Forest",
	stringsAsFactors=FALSE)

out = foreach(i=1:nrow(model_mat), .packages=c("boot","glmmTMB","broom","broom.mixed")) %do% {
	print(paste0("STARTING: ", i))
	attach(model_mat[i,])

	df = data_class[data_class$class_simple %in% class_simple & data_class$type %in% type,]

	if(nrow(df) == 0 | length(unique(df$name)) == 1) return(NULL)
        if("any" %in% covars[[1]] & min(table(df$any, df$y)) == 0) return(NULL) # complete separation
        if("natural" %in% covars[[1]] & min(table(df$natural, df$y)) == 0) return(NULL) # complete separation
        if("hist_loss_binary" %in% covars[[1]] & min(table(df$hist_loss_binary, df$y)) == 0) return(NULL)

	form = as.formula(paste0("cbind(y,1-y) ~ ", paste(covars[[1]],collapse="+"), " + (1 | name)"))
        if(class_simple == "All species")
        	form = as.formula(paste0("cbind(y,1-y) ~ ", paste(covars[[1]],collapse="+"), " + (1 | name) + (1 | group) + (1 | Species.name)")) # UPDATE
	mod = withWarnings(glmmTMB(form, weights=df$dataset.rating, control = glmmTMBControl(optCtrl=list(rel.tol=1e-7)),
		data=df, family=binomial(link = "logit"))) # look into r2 e.g. https://stat.ethz.ch/pipermail/r-sig-mixed-models/2018q1/026405.html
        warn_main = mod$Warnings
        mod = mod$Value
        if(length(grep("onvergence", warn_main)) > 0) return(NULL)
  
        ### output
	out = list(mod_summary=data.frame(id=i, model_mat[i,], n=nrow(df), tidy(mod, effect="fixed"), n_warn=length(warn_main), AIC=AIC(mod)),
                settings=model_mat[i,])
        out$mod_summary$covars = paste(covars[[1]], collapse=";")
	print(paste0("FINISHED: ", i))
	return(out)
}

out_col = list(mod_tab=do.call("rbind",lapply(out,function(x) x$mod_summary)))

out_col$mod_tab = out_col$mod_tab[out_col$mod_tab$term != "(Intercept)",]
out_col$mod_tab$p_adj = p.adjust(out_col$mod_tab$p.value, method="fdr")

saveRDS(out_col, "output/models_disturbance_migratory.RDS")

