data = readRDS("input/model_data.RDS")
data = data[! is.na(data$log_area_km2),] # to keep num. obs. same
data$y = as.numeric(1:nrow(data) %in% grep("Core", data$Category))

data$group = data$class_simple # UPDATE

data_all = data
data_all$class_simple = "All species"
data_class = rbind(data, data_all)

######################### models

model_mat = expand.grid(class_simple=unique(data_class$class_simple),
	covars=list("any","natural",
                    c("any","log_area_km2"),c("any","log_range_edge_km"),
                    c("natural","log_area_km2"),c("natural","log_range_edge_km")),
	type=c("Forest"),
	stringsAsFactors=FALSE)

cl = makeCluster(8, type = "SOCK", outfile="")
registerDoSNOW(cl)
out = foreach(i=1:nrow(model_mat), .packages=c("boot","glmmTMB","broom","broom.mixed")) %dopar% {
	print(paste0("STARTING: ", i))
	attach(model_mat[i,])

        options(nwarnings = 1e7) # need to search all warnings for convergence ones.  If we reach 1e7 throw an error (have to increase nwarnings)

	df = data_class[data_class$type %in% type & data_class$class_simple %in% class_simple,]
        df = df[! is.na(apply(df[,covars[[1]],drop=FALSE],1,sum)),] # only keep obs. w/ all covar data!
	if(nrow(df) == 0 | length(unique(df$name)) == 1) return(NULL)

	form = as.formula(paste0("y ~ ", paste(covars[[1]],collapse="+"), " + (1 | name) + (1 | Species.name)"))
        if(class_simple == "All species")
        	form = as.formula(paste0("cbind(y,1-y) ~ ", paste(covars[[1]],collapse="+"), " + (1 | name) + (1 | group) + (1 | Species.name)")) # UPDATE
	mod = withWarnings(glmmTMB(form, weights=df$dataset.rating, control = glmmTMBControl(optCtrl=list(rel.tol=1e-7)),
		data=df, family=binomial(link = "logit"))) # look into r2 e.g. https://stat.ethz.ch/pipermail/r-sig-mixed-models/2018q1/026405.html
        warn_main = mod$Warnings
        mod = mod$Value
        if(length(grep("onvergence", warn_main)) > 0) return(NULL)

	out = list(mod_summary=data.frame(model_id=i, n_obs=nrow(df), AIC=AIC(mod), model_mat[i,], tidy(mod, effect="fixed"), n_warn=length(warn_main)))
        out$mod_summary$covars = paste(covars[[1]], collapse=";")
	print(paste0("FINISHED: ", i))
	return(out)
}
stopCluster(cl)

out_col = list(mod_tab=do.call("rbind",lapply(out,function(x) x$mod_summary)))

out_col$mod_tab = out_col$mod_tab[out_col$mod_tab$term != "(Intercept)",]
out_col$mod_tab$p_adj = p.adjust(out_col$mod_tab$p.value, method="fdr")

saveRDS(out_col, "output/models_pred_range.RDS")

