models_pred = readRDS("output/models_pred_range.RDS")

mod_tab = models_pred$mod_tab

mod_tab$estimate_trans = exp(mod_tab$estimate) - 1
mod_tab$lower = exp(mod_tab$estimate - qnorm(0.975)*mod_tab$std.error) - 1
mod_tab$upper = exp(mod_tab$estimate + qnorm(0.975)*mod_tab$std.error) - 1

mod_tab = do.call("rbind", lapply(split(mod_tab, paste(mod_tab$class_simple, mod_tab$type)), function(df){
  df$AIC = df$AIC - min(df$AIC)
  df = df[order(df$AIC),]
}))

mod_tab = mod_tab[,c("model_id","class_simple","type","n_obs","term","estimate","std.error","p_adj","estimate_trans","lower","upper","AIC")]
colnames(mod_tab) = c("model_id","Group","Habitat","n","Variable","Estimate","Std. error","p-value","Estimate*","Lower*","Upper*","delta_AIC")

mod_tab[,c("Estimate","Std. error","p-value","Estimate*","Lower*","Upper*","delta_AIC")] = round(mod_tab[,c("Estimate","Std. error","p-value","Estimate*","Lower*","Upper*","delta_AIC")], 3)

mod_tab$`p-value`[mod_tab$`p-value` == 0] = "< 0.001"
mod_tab$Variable = revalue(mod_tab$Variable, c("abs_lat"="Latitude","forest_cover"="Forest cover","log_area_km2"="Range size",
                                               "log_range_edge_km"="Distance to edge","hwi"="Hand wing index",
                                               "anyTRUE"="Any disturbance","naturalTRUE"="Natural disturbance",
                                               "hist_loss_binaryTRUE"="Historical forest loss"))
mod_tab$n = prettyNum(mod_tab$n,big.mark=",")
mod_tab$delta_AIC[mod_tab$delta_AIC == 0] = "-" # technically could have positive delta AIC that rounds to 0.000

### formatting/save

# can't delete whole rows/cols it seems: https://github.com/awalker89/openxlsx/issues/191

wb = write.xlsx(mod_tab, file = "output/model_table_core_SI.xlsx", headerStyle=createStyle(textDecoration = "Bold",border="Bottom"))

setColWidths(wb, sheet = 1, cols = 1:ncol(mod_tab), widths = "auto") # doesn't work great

addStyle(wb, sheet = 1, createStyle(halign = "right"),
         rows = 1:(1+nrow(mod_tab)),
         cols = union(which(sapply(mod_tab, class) == "numeric"), which(colnames(mod_tab) %in% c("n","p-value"))),
         gridExpand = TRUE, stack=TRUE)

for(merge_col in c("Group","Habitat","n")){
        merge_tab = data.frame(rle2(factor(mod_tab[,merge_col]), indices=TRUE))
        for(i in 1:nrow(merge_tab)){
                mergeCells(wb, 1, cols = which(colnames(mod_tab) == merge_col), rows = 1+(merge_tab$start[i]:merge_tab$stop[i]))
                addStyle(wb, sheet = 1, createStyle(halign="center",valign="center"),
                         cols = which(colnames(mod_tab) == merge_col), rows = 1+(merge_tab$start[i]:merge_tab$stop[i]),
                         stack=TRUE)
        }
        addStyle(wb, sheet = 1, createStyle(halign="center"),
                cols = which(colnames(mod_tab) == merge_col), rows = 1,
                stack=TRUE)
}

merge_tab = data.frame(rle2(factor(mod_tab$model_id), indices=TRUE))
for(i in 1:nrow(merge_tab)){
        addStyle(wb, sheet = 1, createStyle(border="Bottom"),
                cols = which(colnames(mod_tab) == "model_id"):ncol(mod_tab), # planned to start at "Variable", but this looks nice!
                rows = 1+merge_tab$stop[i],
                         stack=TRUE, gridExpand=TRUE)
        mergeCells(wb, 1, cols = which(colnames(mod_tab) == "delta_AIC"), rows = 1+(merge_tab$start[i]:merge_tab$stop[i])) # merge delta AIC col. w/in models
        addStyle(wb, sheet = 1, createStyle(halign="right",valign="center"),
                         cols = which(colnames(mod_tab) == "delta_AIC"), rows = 1+(merge_tab$start[i]:merge_tab$stop[i]),
                         stack=TRUE)
}

deleteData(wb, 1, cols=1, rows=1:(nrow(mod_tab)+1), gridExpand=TRUE)
addStyle(wb, sheet = 1, createStyle(),
        cols = 1, rows=1:(nrow(mod_tab)+1),
        stack=FALSE)

addStyle(wb, sheet = 1, createStyle(fgFill="#C6EFCE"),
        cols = which(colnames(mod_tab) == "Variable"):(ncol(mod_tab)-1),
        rows=1+which(as.numeric(mod_tab$`p-value`) < 0.05 | mod_tab$`p-value` == "< 0.001"),
        stack=TRUE, gridExpand=TRUE)

addStyle(wb, sheet = 1, createStyle(halign="right"),
        cols = ncol(mod_tab), rows=1:(nrow(mod_tab)+1),
        stack=TRUE)

saveWorkbook(wb, "output/model_table_core_SI.xlsx", overwrite=TRUE)

