######################### simple table(s)

data = readRDS("input/model_data.RDS")

tab = table(BIOFRAG_cat=data$Category, our_cat=data$modeled_type)
tab = tab[apply(tab,1,sum) > 0,]
sum(diag(tab)) / sum(tab) # ~53% accuracy
sum(diag(tab[-3,-3])) / sum(tab[-3,-3]) # ~69% excl. noPref

tab_sum = addmargins(tab)
write.csv(tab_sum, "output/tab_sum.csv")
write.csv(prop.table(tab,1), "output/tab_prop.csv")

#########################

data = readRDS("input/model_data.RDS")

data$Category = data$modeled_type
data$type = str_split_fixed(data$Category, " ", 2)[,1]

data$group = data$class_simple # UPDATE
data$y = as.numeric(1:nrow(data) %in% grep("Core", data$Category))

data_all = data
data_all$class_simple = "All species"
data_class = rbind(data, data_all)

######################### models

model_mat = expand.grid(class_simple=unique(data_class$class_simple),
	covars=list("any","natural","hist_loss_binary"),
	type="Forest",
        species_policy=c("Random effect","Drop duplicates","none"),
	stringsAsFactors=FALSE)
model_mat$rel_tol = 1e-7
model_mat$rel_tol[model_mat$species_policy == "none"] = 1e-10

cl = makeCluster(8, type = "SOCK", outfile="")
registerDoSNOW(cl)
out = foreach(i=1:nrow(model_mat), .packages=c("boot","glmmTMB","broom","broom.mixed")) %dopar% {
	print(paste0("STARTING: ", i))
	attach(model_mat[i,])
	assignInNamespace("predict.glmmTMB",myPredict, ns="glmmTMB") # substitute fixed function (foreach loads glmmTMB each time)

	df = data_class[data_class$class_simple %in% class_simple & data_class$type %in% type,]
        if(species_policy == "Drop duplicates")
                df = df[! duplicated(df$Species.name),]

	if(nrow(df) == 0 | length(unique(df$name)) == 1) return(NULL)
        if("any" %in% covars[[1]] & min(table(df$any, df$y)) == 0) return(NULL) # complete separation
        if("natural" %in% covars[[1]] & min(table(df$natural, df$y)) == 0) return(NULL) # complete separation
        if("hist_loss_binary" %in% covars[[1]] & min(table(df$hist_loss_binary, df$y)) == 0) return(NULL)

        form = paste0("cbind(y,1-y) ~ ", paste(covars[[1]],collapse="+"), " + (1 | name)")
        if(class_simple == "All species")
        	form = paste0(form, " + (1 | group)")
        if(species_policy == "Random effect" & class_simple != "Herptiles")
        	form = paste0(form, " + (1 | Species.name)")
        form = as.formula(form)

	mod = withWarnings(glmmTMB(form, weights=df$dataset.rating,
		data=df, family=binomial(link = "logit"),
                           control = glmmTMBControl(optCtrl=list(rel.tol=rel_tol))))
        warn_main = mod$Warnings
        mod = mod$Value
        if(length(grep("onvergence", warn_main)) > 0) return(NULL)

	out = list(mod_summary=data.frame(id=i, model_mat[i,], n=nrow(df), tidy(mod, effect="fixed"), n_warn=length(warn_main), AIC=AIC(mod)),
                settings=model_mat[i,])
        out$mod_summary$covars = paste(covars[[1]], collapse=";")
	print(paste0("FINISHED: ", i))
	return(out)
}
stopCluster(cl)

out_col = list(mod_tab=do.call("rbind",lapply(out,function(x) x$mod_summary)))

out_col$mod_tab = out_col$mod_tab[out_col$mod_tab$term != "(Intercept)" & out_col$mod_tab$species_policy == "Random effect",]
out_col$mod_tab$p_adj = p.adjust(out_col$mod_tab$p.value, method="fdr")

saveRDS(out_col, "output/models_disturbance_species_policy_coef.RDS")

